﻿using System;
using System.IO;
using System.Text;
using System.Collections.Generic;
using System.Collections;

using YsTxWLIB;

namespace wlibsamp
{
    // //////////////////////////////////////////////////////////
    /// <summary>MainProc　クラス</summary>
    // //////////////////////////////////////////////////////////
    public static class MainProc
    {
        static string argSrcfile;    //ソースファイル名
        static string argDstfile;    //ディストファイル名
        static string argOutfile;    //出力ファイル名
        static string argOutFmt;     //出力書式モード
        static string argCsvFmt;     //出力ＣＳＶ書式モード

        // ==================================================================
        /// <summary>
        /// 差分出力処理メイン 
        /// </summary>
        /// <param name="args">コマンド引数</param>
        /// <returns> 0=正常　0!= 異常</returns>
        /// <remarks>
        /// 差分出力処理メイン 
        /// </remarks>
        // ==================================================================
        public static int Proc(string[] args)
        {
            int iRet;

            //=======================================
            //  引数チェック         
            //=======================================
            if (args.Length < 5)
            {
                Console.WriteLine("コマンド: ファイルの差分を出力する");
                Console.WriteLine("形式: %s  YsCTxDiff srcfile dstfile outfile");
                Console.WriteLine("引数: 1  (i)srcfile    ソースファイル名");
                Console.WriteLine("      2  (i)dstfile    ディストファイル名");
                Console.WriteLine("      3  (o)outfile    出力ファイル名");
                Console.WriteLine("      4  (i)dfmt       出力書式モード");
                Console.WriteLine("      5  (i)csvfmt     出力ＣＳＶ書式モード");
                return (-1);
            }

            argSrcfile  = args[0]; // ソースファイル名
            argDstfile  = args[1]; // ディストファイル名
            argOutfile  = args[2]; // 出力ファイル名
            argOutFmt = args[3]; // 出力書式モード
            argCsvFmt = args[4]; // 出力ＣＳＶ書式モード

            //=======================================
            //  初期化         
            //=======================================

            //=======================================
            //  開始処理         
            //=======================================
            DateTime mkDate = DateTime.Now; //現在時刻
            Console.WriteLine(" ==========================================================");
            Console.WriteLine("*** wlibsamp 開始 " + mkDate);
            Console.WriteLine(" ==========================================================");

            //=======================================
            //  引数確認         
            //=======================================
            Console.WriteLine("引数1 ソースファイル名   = " + args[0]);
            Console.WriteLine("引数2 ディストファイル名 = " + args[1]);
            Console.WriteLine("引数3 出力ファイル名     = " + args[2]);
            Console.WriteLine("引数4 出力書式モード     = " + args[3]);
            Console.WriteLine("引数5 出力ＣＳＶ書式モード     = " + args[4]);

            //=======================================
            //  本処理         
            //=======================================
            List<String> srcflAry;
            List<String> dstflAry;

            String txtFile1 = argSrcfile;
            String txtFile2 = argDstfile;

            // テキスト差分オブジェクト生成・オープン
            YsTxWDiff txdf = new YsTxWDiff();
            txdf.Init();
            txdf.Open(YsTxWDiff.DefDifDif);

            //ファイルを文字列に読み込む
            iRet = txdf.ReadFile(txtFile1, out srcflAry);
            iRet = txdf.ReadFile(txtFile2, out dstflAry);

            List<YsTxWLIB.diffStct> dfList1;
            List<String> fmtList;

            //差分比較
            dfList1 = txdf.MakeDiffStr(srcflAry, dstflAry);

            //文字列を書式化する
            int outfmt = int.Parse (argOutFmt);
            int csvfmt = int.Parse (argCsvFmt);
            fmtList = txdf.FmtDiffList(outfmt, csvfmt, dfList1);

            //ファイルに書き出す
            txdf.WriteFile(argOutfile, fmtList);

            Console.WriteLine("変更無し行 = " + txdf.DifNorLine);
            Console.WriteLine("追加行 = " + txdf.DifAddLine);
            Console.WriteLine("削除行 = " + txdf.DifDelLine);
            Console.WriteLine("変更行 = " + txdf.DifChgLine);

            // テキスト差分オブジェクトクローズ
            txdf.Close();

            //=======================================
            //  終了         
            //=======================================
            mkDate = DateTime.Now; //現在時刻
            Console.WriteLine(" ==========================================================");
            Console.WriteLine("*** wlibsamp 終了 " + mkDate);
            Console.WriteLine(" ==========================================================");

            return(0);
        }

    }
    // //////////////////////////////////////////////////////////
    /// <summary>wlibsamp　クラス</summary>
    // //////////////////////////////////////////////////////////
    class wlibsamp
    {
        // ==================================================================
        /// <summary>
        /// メイン関数 
        /// </summary>
        /// <param name="args">コマンド引数</param>
        /// <returns> 0=正常　0!= 異常</returns>
        /// <remarks>
        /// メイン関数処理 
        /// </remarks>
        // ==================================================================
        static void Main(string[] args)
        {
            int iRet;

            iRet = MainProc.Proc(args);
        
        }
    }
}
